package br.com.cuidai.sdk.cuidai_plugin

import android.app.Activity
import android.util.Log
import androidx.annotation.NonNull
import br.com.cuidai.router.Router.route
import br.com.cuidai.sdk.CuidaiSDK

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** CuidaiPlugin */
class CuidaiPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
	/// The MethodChannel that will the communication between Flutter and native Android
	///
	/// This local reference serves to register the plugin with the Flutter Engine and unregister it
	/// when the Flutter Engine is detached from the Activity
	private lateinit var channel: MethodChannel

	private var activity: Activity? = null

	override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
		channel = MethodChannel(flutterPluginBinding.binaryMessenger, "cuidai_plugin")
		channel.setMethodCallHandler(this)
	}

	override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
		when (call.method) {
			"initSDK" -> {
				val params: String? = (call.arguments as? HashMap<*, *>)?.get("params")?.toString()
				activity?.let {
					CuidaiSDK.initWithParams(it.application, params ?: "")
				}
			}
			"getPlatformVersion" -> {
				result.success("Android ${android.os.Build.VERSION.RELEASE}")
			}
			"openChat" -> {
				activity?.route("default")
			}
			"route" -> {
				val route: String? = (call.arguments as? HashMap<*, *>)?.get("route")?.toString()
				route?.replace("flutter://", "")?.let {
					activity?.route(it)
				}
			}
			else -> {
				result.notImplemented()
			}
		}
	}

	override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
		channel.setMethodCallHandler(null)
	}

	override fun onAttachedToActivity(binding: ActivityPluginBinding) {
		this.activity = binding.activity
	}

	override fun onDetachedFromActivityForConfigChanges() {}

	override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {}

	override fun onDetachedFromActivity() {}
}
