import Flutter
import UIKit
import CuidaiSDK

private enum CuidaiCommand: String {
    case initSDK
    case openChat
    case route
}

public class SwiftCuidaiPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "cuidai_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftCuidaiPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    result("iOS " + UIDevice.current.systemVersion)

    guard let command = CuidaiCommand(rawValue: call.method) else {
        return
    }
    
    switch command {
    case .initSDK:
        guard let map = call.arguments as? [String: Any],
              let params = map["params"] as? String
        else {
            return
        }

        Cuidai.instantiate(
            params: params,
            authenticator: { () -> String in
                return ""
            },
            subscriber: {
                return true
            },
            // tracker: { (events) in
            //     #if DEBUG
            //     print("SDK events \(events)")
            //     #endif
            // },
            tagger: { (tags) in
                #if DEBUG
                print("SDK tags \(tags)")
                #endif
            },
            router: { (route) in
                #if DEBUG
                print("SDK route \(route)")
                #endif
            }
        )

    case .openChat:
        Cuidai.open("cuidai://chatbot")

    case .route:
        guard
            let map = call.arguments as? [String: Any],
            let route = map["route"] as? String
        else {
            return
        }
        Cuidai.open(route)
    }
  }
}
